function Generate_Fig_3
r = [2.8; 2.85];
K = [1000000; 1002300];
nsample = round(1.3*K(1)*(2.^(-2.75:0.25:0)));
tmax = 1e5;
iterations = 1e5; 

fig1 = 110;
figure(fig1), clf
plot_pred(r,K,K(1)/10,K(1)*1.5)
hold on
drawnow
figure(fig1+1), clf
plot_pred(flipud(r),flipud(K),K(2)/10,K(2)*1.5)
hold on
drawnow
pp1 = sim_invP(r,K, nsample, tmax, iterations,fig1);

pp2 = sim_invP(flipud(r),flipud(K),nsample, tmax, iterations,fig1+1);


function plot_pred(r,K,n1,n2)
n=0;
tmax = 1e5;
while n(end)==0
	n = popsim(r(1),K(1),tmax);
end
nh = 1/mean(1./n);
f = log(1+diag(r)*(1-(1./K)*n));
s = mean(f(2,:)-f(1,:));
hold on
n0plot = linspace(n1,n2,100);
plot(n0plot,s*nh./n0plot,'--m')
logxy
xaxis(0.15e6, 2e6)
raxis
nbins = 1e6*10.^(-1.1:0.01:1);
hist(n,nbins);
logx
xaxis(0.15e6, 2e6)
laxis
drawnow


function n = popsim(r,K,tmax)
n = zeros(1,tmax);
n(1) = K*0.5;
for t=2:tmax
	f = 1+r*(1-n(t-1)/K) + 1e-3*randn;
	p = 1./(1+f);
	n(t) = nbinrndAppr(n(t-1),p);
 	if n(t)==0, warning('extinction!'), break, end
	if rem(t,100)==0, drawnow, end
end
n = n(100:end);



function [pp,nn0] = sim_invP(r,K,nsample,tmax,iterations, fig)
pp = zeros(1,length(nsample));
for si=length(nsample):-1:1
	invasions = 0;
	ambiguous = 0;
	N = zeros(2,tmax);
	for iter = 1:iterations
		n=[nsample(si)-1;1];
		for t=1:tmax
			N(:,t)=n;
			f = max(0,1+r.*(1-sum(n)./K) + 1e-3*randn);
			p = 1./(1+f);
			n(1) = nbinrndAppr(n(1),p(1));
			n(2) = nbinrndAppr(n(2),p(2));
			if n(2)==0
				break
			elseif n(2)>K(2)/10 % invasion limit
				invasions = invasions+1;
				break
			end
		end
		drawnow
		if t==tmax
			ambiguous = ambiguous+1;
		end
	end
	pp(si) = invasions/iterations;
	figure_quiet(fig)
	logxy
	[phat,ci] = binofit(invasions,iterations,0.05);
	errorbar(nsample(si),phat,phat-ci(1),ci(2)-phat,'.')
	hold on
	drawnow

end


